%define nginx_user      nginx
%define nginx_group     %{nginx_user}
%define nginx_home      %{_localstatedir}/lib/nginx
%define nginx_home_tmp  %{nginx_home}/tmp
%define nginx_logdir    %{_localstatedir}/log/nginx
%define nginx_confdir   %{_sysconfdir}/nginx
%define nginx_datadir   %{_datadir}/nginx
%define nginx_webroot   %{nginx_datadir}/html

Name:           tengine
version:        1.4.6
Release:        7.7
Summary:        Robust, small and high performance http and reverse proxy server forked from nginx
Group:          System Environment/Daemons   

License:        BSD
URL:            http://tengine.taobao.org/ 
BuildRoot:      %{_tmppath}/%{name}-%{version}-root

BuildRequires:      pcre-devel,zlib-devel,openssl-devel,perl(ExtUtils::Embed)
BuildRequires:	    GeoIP-devel, libxml2-devel, libxslt-devel, gd-devel, lua-devel

Requires:           pcre,zlib,openssl
Requires:           perl(:MODULE_COMPAT_%(eval "`%{__perl} -V:version`"; echo $version))
Requires(pre):      shadow-utils
Requires(post):     chkconfig
Requires(preun):    chkconfig, initscripts
Requires(postun):   initscripts

Source0:    tengine-%{version}.tar.gz
Source1:    %{name}.init
Source2:    %{name}.logrotate
Source3:    virtual.conf
Source4:    ssl.conf
Source7:    %{name}.sysconfig

Patch0:     nginx-auto-cc-gcc.patch
Patch1:     nginx-conf-0.7.x.patch

%description
Tengine is a web server originated by Taobao, the largest e-commerce website in Asia. 
It is based on Nginx HTTP server and has many advanced features. Tengine has been proven 
very stable and efficient on the top 100 global websites, including taobao.com and tmall.com. 

100% NGiNX compatible


%prep
%setup -q

%patch0 -p0
%patch1 -p0

%build
export DESTDIR=%{buildroot}
./configure \
    --user=%{nginx_user} \
    --group=%{nginx_group} \
    --prefix=%{nginx_datadir} \
    --sbin-path=%{_sbindir}/%{name} \
    --conf-path=%{nginx_confdir}/%{name}.conf \
    --error-log-path=%{nginx_logdir}/error.log \
    --http-log-path=%{nginx_logdir}/access.log \
    --http-client-body-temp-path=%{nginx_home_tmp}/client_body \
    --http-proxy-temp-path=%{nginx_home_tmp}/proxy \
    --http-fastcgi-temp-path=%{nginx_home_tmp}/fastcgi \
    --pid-path=%{_localstatedir}/run/%{name}.pid \
    --lock-path=%{_localstatedir}/lock/subsys/%{name} \
    --with-http_ssl_module \
    --with-http_realip_module \
    --with-http_addition_module \
    --with-http_sub_module \
    --with-http_dav_module \
    --with-http_flv_module \
    --with-http_gzip_static_module \
    --with-http_stub_status_module \
    --with-http_geoip_module \
    --with-http_slice_module \
    --with-http_secure_link_module \
    --with-http_degradation_module \
    --with-http_sysguard_module \
    --with-http_concat_module \
    --with-http_mp4_module \
    --with-mail \
    --with-mail_ssl_module \
    --with-debug \
    --with-ipv6 \
    --with-http_xslt_module \
    --with-http_image_filter_module \
    --with-http_random_index_module \
    --with-http_sysguard_module=shared \
    --with-http_charset_filter_module=shared \
    --with-http_userid_filter_module=shared \
    --with-http_footer_filter_module=shared \
    --with-http_referer_module=shared \
    --with-http_rewrite_module=shared \
    --with-http_fastcgi_module=shared \
    --with-http_uwsgi_module=shared \
    --with-http_scgi_module=shared \
    --with-http_memcached_module=shared \
    --with-http_limit_conn_module=shared \
    --with-http_limit_req_module=shared \
    --with-http_empty_gif_module=shared \
    --with-http_browser_module=shared \
    --with-http_user_agent_module=shared \
    --with-http_upstream_ip_hash_module=shared \
    --with-http_upstream_least_conn_module=shared \
    --with-http_upstream_session_sticky_module=shared \
    --with-http_split_clients_module=shared \
    --with-http_lua_module \
    --with-cc-opt="%{optflags} $(pcre-config --cflags)" \
    --with-file-aio \
    --with-syslog 

make %{?_smp_mflags} 


%install
rm -rf %{buildroot}
make install DESTDIR=%{buildroot} INSTALLDIRS=vendor
find %{buildroot} -type f -name .packlist -exec rm -f {} \;
find %{buildroot} -type f -name perllocal.pod -exec rm -f {} \;
find %{buildroot} -type f -empty -exec rm -f {} \;
find %{buildroot} -type f -exec chmod 0644 {} \;
find %{buildroot} -type f -name '*.so' -exec chmod 0755 {} \;
chmod 0755 %{buildroot}%{_sbindir}/tengine
%{__install} -p -D -m 0755 %{SOURCE1} %{buildroot}%{_initrddir}/%{name}
%{__install} -p -D -m 0644 %{SOURCE2} %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
%{__install} -p -D -m 0644 %{SOURCE7} %{buildroot}%{_sysconfdir}/sysconfig/%{name}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_confdir}/conf.d
%{__install} -p -m 0644 %{SOURCE3} %{SOURCE4} %{buildroot}%{nginx_confdir}/conf.d
%{__install} -p -d -m 0755 %{buildroot}%{nginx_home_tmp}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_logdir}
%{__install} -p -d -m 0755 %{buildroot}%{nginx_webroot}

# convert to UTF-8 all files that give warnings.
for textfile in CHANGES
do
    mv $textfile $textfile.old
    iconv --from-code ISO8859-1 --to-code UTF-8 --output $textfile $textfile.old
    rm -f $textfile.old
done

%clean
rm -rf %{buildroot}

%pre
%{_sbindir}/useradd -c "Nginx user" -s /bin/false -r -d %{nginx_home} %{nginx_user} 2>/dev/null || :

%post
/sbin/chkconfig --add %{name}

%preun
if [ $1 = 0 ]; then
    /sbin/service %{name} stop >/dev/null 2>&1
    /sbin/chkconfig --del %{name}
fi

%postun
if [ $1 -ge 1 ]; then
    /sbin/service %{name} condrestart > /dev/null 2>&1 || :
fi

%files
%defattr(-,root,root,-)
%{nginx_datadir}/
%{_sbindir}/%{name}
# %{_mandir}/man3/%{name}.3pm.gz
%{_initrddir}/%{name}
%dir %{nginx_confdir}
%dir %{nginx_confdir}/conf.d
%config(noreplace) %{nginx_confdir}/conf.d/*.conf
%config(noreplace) %{nginx_confdir}/win-utf
#%config(noreplace) %{nginx_confdir}/%{name}.conf.default
%config(noreplace) %{nginx_confdir}/mime.types.default
%config(noreplace) %{nginx_confdir}/fastcgi_params
%config(noreplace) %{nginx_confdir}/fastcgi_params.default
%config(noreplace) %{nginx_confdir}/fastcgi.conf
%config(noreplace) %{nginx_confdir}/fastcgi.conf.default
%config(noreplace) %{nginx_confdir}/scgi_params
%config(noreplace) %{nginx_confdir}/scgi_params.default
%config(noreplace) %{nginx_confdir}/uwsgi_params           
%config(noreplace) %{nginx_confdir}/uwsgi_params.default
%config(noreplace) %{nginx_confdir}/koi-win
%config(noreplace) %{nginx_confdir}/koi-utf
%config(noreplace) %{nginx_confdir}/%{name}.conf
%config(noreplace) %{nginx_confdir}/mime.types
%config(noreplace) %{nginx_confdir}/browsers
%config(noreplace) %{nginx_confdir}/module_stubs
%config(noreplace) %{nginx_confdir}/nginx.conf.default


%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}

#%dir %{perl_vendorarch}/auto/%{name}
#%{perl_vendorarch}/%{name}.pm
#%{perl_vendorarch}/auto/%{name}/%{name}.so
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_home_tmp}
%attr(-,%{nginx_user},%{nginx_group}) %dir %{nginx_logdir}


%changelog
* Fri May 27 2013 Juergen Gotteswinter <jg@internetx.de> - 1.4.6-1
- initial tengine build 1.4.6

* Fri May 24 2013 Juergen Gotteswinter <jg@internetx.de> - 1.4.5-1
- initial tengine build 1.4.5
